@@ -16,7 +16,7 @@ use namespace::autoclean;
 
 requires 'run_tests';
 
-our $VERSION = 'v0.2.1';
+our $VERSION = 'v0.2.2';
 
 
 sub _build_data_files {
@@ -150,7 +150,7 @@ Test::Roo::DataDriven - simple data-driven tests with Test::Roo
 
 =head1 VERSION
 
-version v0.2.1
+version v0.2.2
 
 =head1 SYNOPSIS
 
@@ -364,7 +364,8 @@ unloaded.
 
 =head2 Skipping test cases
 
-Skipping a test case in your test class, e.g.
+Skipping a test case in your test class as per L<Test::Roo::Cookbook>,
+e.g.
 
   sub BUILD {
     my ($self) = @_;
@@ -377,6 +378,16 @@ Skipping a test case in your test class, e.g.
 
 will stop all remaining tests from running.
 
+Instead, skip tests before the setup:
+
+    before setup => sub {
+        my ($self) = @_;
+
+        ...
+
+        plan skip_all => 'test skips';
+    };
+
 =head2 Prerequisite Scanners
 
 Prerequisite scanners used for build tools may not recognise modules
